clixx.groups
============

.. currentmodule:: clixx.groups

Classes
-------

.. autoclass:: _Group
    :members:
    :special-members: __len__, __iter__, __iadd__
    :show-inheritance:

.. autoclass:: ArgumentGroup
    :members:
    :show-inheritance:

.. autoclass:: OptionGroup
    :members:
    :show-inheritance:

.. autoclass:: CommandGroup
    :members:
    :show-inheritance:

Enumerations
------------

.. autoclass:: GroupType
    :members:
    :show-inheritance:

.. autodata:: ANY

.. autodata:: ALL

.. autodata:: NONE

.. autodata:: AT_LEAST_ONE

.. autodata:: AT_MOST_ONE

.. autodata:: EXACTLY_ONE
